@@ -30,7 +30,7 @@
 #include "sid_test.h"
 
 enum {
-  LOADER_LIST_SONG_NAME,
+  LOADER_LIST_SONG_NAME = 0,
   LOADER_LIST_SONG_URI,
   LOADER_LIST_SONG_SHORT_URI,
   LOADER_LIST_NUM_COLS
