@@ -29,8 +29,8 @@
 
 enum
   {
-    PLAYER_LIST_SONG_NAME,
-    PLAYER_LIST_SONG_AUTHOR,
+    PLAYER_LIST_SONG_NAME = 0,
+    PLAYER_LIST_SONG_AUTHOR = 1,
     PLAYER_LIST_SONG_AMOUNT,
     PLAYER_LIST_SONG_PATH,
     PLAYER_LIST_NUM_COLS
