@@ -25,6 +25,9 @@
 #include <string.h>
 #include <curl/curl.h>
 
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #include "debug.h"
 
 unsigned int
