@@ -15,12 +15,20 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
+#include "plugins/debug.h"
+
 unsigned int
 create_sid_path(const char *path);
 
 unsigned int
 sidtune_is_ok(const gchar *path);
 
+unsigned int
+directory_size(const gchar *path);
+
+unsigned int
+truncate_cache_dir(const gchar *path, unsigned int limit);
+
 #ifdef HILDON
 unsigned int mmc_ok();
 #endif
